@@ -188,6 +188,10 @@ class GithubObject(object):
     def _makeListOfIntsAttribute(value):
         return GithubObject.__makeSimpleListAttribute(value, int)
 
+    @staticmethod
+    def _makeListOfDictsAttribute(value):
+        return GithubObject.__makeSimpleListAttribute(value, dict)
+
     @staticmethod
     def _makeListOfListOfStringsAttribute(value):
         return GithubObject.__makeSimpleListAttribute(value, list)
@@ -199,8 +203,8 @@ class GithubObject(object):
             return _BadAttribute(value, [dict])
 
     def _makeDictOfStringsToClassesAttribute(self, klass, value):
-        if isinstance(value, dict) and all(isinstance(key, str) and isinstance(element, dict) for key, element in iter(value.items())):
-            return _ValuedAttribute(dict((key, klass(self._requester, self._headers, element, completed=False)) for key, element in iter(value.items())))
+        if isinstance(value, dict) and all(isinstance(key, str) and isinstance(element, dict) for key, element in value.items()):
+            return _ValuedAttribute(dict((key, klass(self._requester, self._headers, element, completed=False)) for key, element in value.items()))
         else:
             return _BadAttribute(value, {(str, str): dict})
 
