@@ -1,11 +1,14 @@
 # -*- coding: utf-8 -*-
 
-# ########################## Copyrights and license ############################
+############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2014 Vincent Jacques <vincent@vincent-jacques.net>                 #
+# Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
+# Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
-# http://pygithub.github.io/PyGithub/v1/index.html                             #
+# http://pygithub.readthedocs.io/                                              #
 #                                                                              #
 # PyGithub is free software: you can redistribute it and/or modify it under    #
 # the terms of the GNU Lesser General Public License as published by the Free  #
@@ -20,7 +23,7 @@
 # You should have received a copy of the GNU Lesser General Public License     #
 # along with PyGithub. If not, see <http://www.gnu.org/licenses/>.             #
 #                                                                              #
-# ##############################################################################
+################################################################################
 
 from . import Framework
 import github
@@ -32,7 +35,7 @@ class Issue140(Framework.TestCase):  # https://github.com/jacquev6/PyGithub/issu
         self.repo = self.g.get_repo("twitter/bootstrap")
 
     def testGetDirContentsThenLazyCompletionOfFile(self):
-        contents = self.repo.get_dir_contents("/js")
+        contents = self.repo.get_dir_contents("js")
         self.assertEqual(len(contents), 15)
         n = 0
         for content in contents:
@@ -45,10 +48,10 @@ class Issue140(Framework.TestCase):  # https://github.com/jacquev6/PyGithub/issu
         self.assertEqual(n, 2)
 
     def testGetFileContents(self):
-        contents = self.repo.get_file_contents("/js/bootstrap-affix.js")
+        contents = self.repo.get_file_contents("js/bootstrap-affix.js")
         self.assertEqual(contents.encoding, "base64")
         self.assertEqual(contents.url, "https://api.github.com/repos/twitter/bootstrap/contents/js/bootstrap-affix.js")
         self.assertEqual(len(contents.content), 4722)
 
     def testGetDirContentsWithRef(self):
-        self.assertEqual(len(self.repo.get_dir_contents("/js", "8c7f9c66a7d12f47f50618ef420868fe836d0c33")), 15)
+        self.assertEqual(len(self.repo.get_dir_contents("js", "8c7f9c66a7d12f47f50618ef420868fe836d0c33")), 15)
