@@ -10,6 +10,10 @@
 # Copyright 2016 Peter Buckley <dx-pbuckley@users.noreply.github.com>          #
 # Copyright 2017 Balázs Rostás <rostas.balazs@gmail.com>                     #
 # Copyright 2018 Anton Nguyen <afnguyen85@gmail.com>                           #
+# Copyright 2018 Jacopo Notarstefano <jacopo.notarstefano@gmail.com>           #
+# Copyright 2018 Jasper van Wanrooy <jasper@vanwanrooy.net>                    #
+# Copyright 2018 Raihaan <31362124+res0nance@users.noreply.github.com>         #
+# Copyright 2018 Tim Boring <tboring@hearst.com>                               #
 # Copyright 2018 sfdye <tsfdye@gmail.com>                                      #
 #                                                                              #
 # This file is part of PyGithub.                                               #
@@ -30,6 +34,8 @@
 #                                                                              #
 ################################################################################
 
+import github
+
 from . import Framework
 
 import datetime
@@ -47,6 +53,7 @@ class Organization(Framework.TestCase):
         self.assertEqual(self.org.collaborators, 9)
         self.assertEqual(self.org.company, None)
         self.assertEqual(self.org.created_at, datetime.datetime(2014, 1, 9, 16, 56, 17))
+        self.assertEqual(self.org.description, 'BeaverSoftware writes software.')
         self.assertEqual(self.org.disk_usage, 2)
         self.assertEqual(self.org.email, '')
         self.assertEqual(self.org.followers, 0)
@@ -69,7 +76,7 @@ class Organization(Framework.TestCase):
         self.assertEqual(self.org.url, "https://api.github.com/orgs/BeaverSoftware")
 
         # test __repr__() based on this attributes
-        self.assertEqual(self.org.__repr__(), 'Organization(name="BeaverSoftware", id=1)')
+        self.assertEqual(self.org.__repr__(), 'Organization(login="BeaverSoftware")')
 
     def testAddMembersDefaultRole(self):
         lyloa = self.g.get_user("lyloa")
@@ -93,10 +100,11 @@ class Organization(Framework.TestCase):
         self.org.edit()
 
     def testEditWithAllArguments(self):
-        self.org.edit("BeaverSoftware2@vincent-jacques.net", "http://vincent-jacques.net", "Company edited by PyGithub", "BeaverSoftware2@vincent-jacques.net", "Location edited by PyGithub", "Name edited by PyGithub")
+        self.org.edit("BeaverSoftware2@vincent-jacques.net", "http://vincent-jacques.net", "Company edited by PyGithub", "Description edited by PyGithub", "BeaverSoftware2@vincent-jacques.net", "Location edited by PyGithub", "Name edited by PyGithub")
         self.assertEqual(self.org.billing_email, "BeaverSoftware2@vincent-jacques.net")
         self.assertEqual(self.org.blog, "http://vincent-jacques.net")
         self.assertEqual(self.org.company, "Company edited by PyGithub")
+        self.assertEqual(self.org.description, "Description edited by PyGithub")
         self.assertEqual(self.org.email, "BeaverSoftware2@vincent-jacques.net")
         self.assertEqual(self.org.location, "Location edited by PyGithub")
         self.assertEqual(self.org.name, "Name edited by PyGithub")
@@ -195,7 +203,8 @@ class Organization(Framework.TestCase):
     def testCreateRepoWithAllArguments(self):
         team = self.org.get_team(141496)
         repo = self.org.create_repo(name="TestPyGithub2", description="Repo created by PyGithub", homepage="http://foobar.com",
-                                    private=False, has_issues=False, has_wiki=False, has_downloads=False, team_id=team.id)
+                                    private=False, has_issues=False, has_projects=False, has_wiki=False, has_downloads=False,
+                                    team_id=team.id, allow_squash_merge=False, allow_merge_commit=False, allow_rebase_merge=True)
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/TestPyGithub2")
 
     def testCreateRepositoryWithAutoInit(self):
@@ -206,3 +215,35 @@ class Organization(Framework.TestCase):
         pygithub = self.g.get_user("jacquev6").get_repo("PyGithub")
         repo = self.org.create_fork(pygithub)
         self.assertEqual(repo.url, "https://api.github.com/repos/BeaverSoftware/PyGithub")
+
+    def testInviteUserWithNeither(self):
+        with self.assertRaises(AssertionError) as raisedexp:
+            self.org.invite_user()
+        self.assertEqual("specify only one of email or user", str(raisedexp.exception))
+
+    def testInviteUserWithBoth(self):
+        jacquev6 = self.g.get_user('jacquev6')
+        with self.assertRaises(AssertionError) as raisedexp:
+            self.org.invite_user(email='foo', user=jacquev6)
+        self.assertEqual("specify only one of email or user", str(raisedexp.exception))
+
+    def testInviteUserByName(self):
+        jacquev6 = self.g.get_user('jacquev6')
+        self.org.invite_user(user=jacquev6)
+
+    def testInviteUserByEmail(self):
+        self.org.invite_user(email='foo@example.com')
+
+    def testInviteUserWithRoleAndTeam(self):
+        team = self.org.create_team("Team created by PyGithub")
+        self.org.invite_user(email='foo@example.com', role='billing_manager', teams=[team])
+
+    def testInviteUserAsNonOwner(self):
+        with self.assertRaises(github.GithubException) as raisedexp:
+            self.org.invite_user(email='bar@example.com')
+        self.assertEqual(raisedexp.exception.status, 403)
+        self.assertEqual(raisedexp.exception.data, {
+            'documentation_url': 'https://developer.github.com/v3/orgs/members/#create-organization-invitation',
+            'message': 'You must be an admin to create an invitation to an organization.'
+            }
+        )
